@@ -1,6 +1,6 @@
 import requests
 
-def get_books_from_naver(self, query, **kwargs):
+def get_books_by_query(query, **kwargs):
     headers = kwargs.get("headers", None)
     display = kwargs.get("display", 10)
     start = kwargs.get("start", 1)
